import React, { useRef } from 'react';
import { CalendarVisController } from '../calendarvis.controller';
import { DateValue } from '../calendarvis.types';
import { getContrastColor } from '../calendarvis.utils';
import { PIXELHEIGHT, PIXELWIDTH, getColor } from './TimelineTable';

export const Day = ({ data, controller }: { data: DateValue[]; controller: CalendarVisController }) => {
  const ref = useRef<HTMLElement>(null);
  const quadrat = String.fromCharCode(9632); // Unicode for Quadrat character

  if (data.length === 0) return null;
  const dateString = data[0].date.toLocaleDateString('default', { weekday: 'short', month: 'short', day: 'numeric', year: 'numeric'});
  const day = data[0].date.getDate();

  // TODO needs visuals
  const aggregateValue = data.reduce((acc, curr) => {
    return acc + curr.value;
  }, 0);

  const color = getColor(aggregateValue, controller.getStats());

  const divStyle: React.CSSProperties = {
    display: 'flex',
    color: color,
    // backgroundColor: 'red',
    width: PIXELWIDTH + 'px',
    height: PIXELHEIGHT + 'px',
    fontSize: '1.2em',
  };

  if (controller.getShowDayLabel() === true) {
    return (
      <div className="day relative flex items-center justify-center" data-key={`${dateString}`}>
        <span style={{ zIndex: 1, color: getContrastColor(color) }} className="absolute text-[8px]">
          {day}
        </span>
        <span
          title={`${dateString}: ${aggregateValue}`}
          onClick={() => console.log(dateString, aggregateValue, data)}
          key={`${dateString}`}
          style={divStyle}
          className="items-center justify-center cursor-pointer"
        >
          {quadrat}
        </span>
      </div>
    );
  }

  return (
    <span
      title={`${dateString}: ${aggregateValue}`}
      onClick={() => console.log(dateString, aggregateValue, data)}
      key={`${dateString}`}
      style={divStyle}
      className="day items-center justify-center hover:border hover:border-collapse "
    >
      {quadrat}
    </span>
  );
};
