import { DateAggregate, MONTHLABEL } from '../calendarvis.const';
import { CalendarVisController } from '../calendarvis.controller';
import { getWeeksInMonth } from '../calendarvis.utils';
import { Week } from './Week';

export const Month = ({ year, month, controller }: { year: number; month: number; controller: CalendarVisController }) => {
  const data = controller.getModelItemsInYearAndMonth(year, month);
  if (data.length === 0) return null;
  // const year = data[0].date.getFullYear();
  // const month = data[0].date.getMonth();
  const monthName = data[0].date.toLocaleString('default', { year: '2-digit', month: MONTHLABEL });

  const weeksInMonth = getWeeksInMonth(year, month);

  // TODO needs visuals
  if (controller.getAggregate() === DateAggregate.months) {
    const aggregateValue = data.reduce((acc, curr) => {
      return acc + curr.value;
    }, 0);

    return (
      <div>
        Aggregate month {monthName}: {aggregateValue}
      </div>
    );
  }

  return (
    <div className="flex flex-col">
      {controller.getShowMonthLabel() && (
        <div className="border border-b-0 border-r-0 border-gray-200 select-none text-3xs">{monthName}</div>
      )}

      <div className="flex flex-row">
        {weeksInMonth.map((week: number, index) => {
          return <Week key={`${year}-${monthName}-${week}`} year={year} weekNumber={week} controller={controller} />;
        })}
      </div>
    </div>
  );
};
