import { interpolateOrRd, rgb, scaleSequential } from 'd3';
import React from 'react';
import { DateAggregate } from '../calendarvis.const';
import { CalendarVisController } from '../calendarvis.controller';
import { DaysOfWeekLabel } from './DaysOfWeekLabel';
import { Year } from './Year';
import styles from '../calendarvis.module.scss';

export const PIXELWIDTH = 14;
export const PIXELHEIGHT = PIXELWIDTH;

const TimelineTable: React.FC<{ controller: CalendarVisController; onMouseUp: (event: React.MouseEvent) => void }> = ({
  controller,
  onMouseUp,
}) => {
  if (controller.getModel().length === 0) return null;

  return (
    <div className="h-full w-full flex flex-row overflow-auto text-xs cursor-pointer" onMouseUp={onMouseUp}>
      {controller.getAggregate() === DateAggregate.days && <DaysOfWeekLabel controller={controller} />}
      {Array.from(controller.getYears(), (year, _) => (
        <Year key={`year-${year}`} year={year} controller={controller} />
      ))}
    </div>
  );
};

export const getColor = (value = Infinity, stats = { min: -Infinity, max: Infinity, avg: Infinity }) => {
  if (value === Infinity) {
    const randomColor = Math.floor(Math.random() * 16777215).toString(16);
    return `#${randomColor}`;
  } else {
    // const normalizedValue = (value - stats.min) / (stats.max - stats.min);
    // const minColor = d3.color(dataColors.orange[5]);
    // const maxColor = d3.color(dataColors.orange[100]);
    // const colorScale = d3.scaleLinear().domain([stats.min, stats.max]).range(['red', 'blue']);
    const colorScale = scaleSequential(interpolateOrRd).domain([stats.min, stats.max]);
    // const colorScale = scaleSequential().domain([stats.min, stats.max]);
    // const colorScale = scaleDiverging((t) => interpolateRdBu(1 - t)).domain([stats.min, stats.avg, stats.max]);

    const colorValue = rgb(colorScale(value)).formatHex();

    // console.log(`#${colorScale(value)}`, colorValue, stats.min, stats.max, normalizedValue);
    return colorValue;
  }
};

export default TimelineTable;
