import { DateAggregate, Days } from '../calendarvis.const';
import { CalendarVisController } from '../calendarvis.controller';
import { Day } from './Day';
import { EmptyDay } from './EmptyDay';

export const Week = ({
  year,
  weekNumber,
  controller,
}: {
  year: number;
  weekNumber: number;
  controller: CalendarVisController;
}) => {
  const data = controller.getModelItemsInYearAndWeek(year, weekNumber);
  if (data.length === 0 && controller.getCollapsedWeeks() === true) return null; //TODO return EmptyWeek?

  // TODO needs visuals
  if (controller.getAggregate() === DateAggregate.weeks) {
    const aggregateValue = data.reduce((acc, curr) => {
      return acc + curr.value;
    }, 0);

    return (
      <div>
        Aggregate week {weekNumber}: {aggregateValue}
      </div>
    );
  }
  return (
    <div className="flex flex-col items-stretch">
      {controller.getShowWeekLabel() && (
        <div className="text-center border border-r-0 border-gray-200 select-none text-3xs">{weekNumber}</div>
      )}
      <div className="flex flex-col p-0 m-0 leading-[0.5rem]">
        {Days.map((day, index) => {
          const filteredData = data.filter((item) => {
            const date = new Date(item.date);
            const dayIndex = (date.getDay() + 6) % 7;
            return dayIndex === index;
          });

          if (filteredData.length === 0) return <EmptyDay key={`${weekNumber}-${index}`} />;
          return <Day key={`${weekNumber}-${index}`} controller={controller} data={filteredData} />;
        })}
      </div>
    </div>
  );
};
