import { DateAggregate, months } from '../calendarvis.const';
import { CalendarVisController } from '../calendarvis.controller';
import { Month } from './Month';

export const Year = ({ year, controller }: { year: number; controller: CalendarVisController }) => {
  const data = controller.getModelItemsInYear(year);
  if (data.length === 0) return null;
  // const year = data[0].date.getFullYear();

  if (controller.getAggregate() === DateAggregate.years) {
    const aggregateValue = data.reduce((acc, curr) => {
      return acc + curr.value;
    }, 0);

    return (
      <div>
        Aggregate year {year}: {aggregateValue}
      </div>
    );
  }

  return (
    <div className="flex flex-col items-stretch">
      {controller.getShowYearLabel() && (
        <span className="sticky left-0 bg-white border border-b-0 border-r-0 border-gray-200 select-none">{year}</span>
      )}
      <div className="flex flex-row">
        {months.map((month, index) => {
          return <Month key={`${year}-${month}`} year={year} month={index} controller={controller} />;
        })}
      </div>
    </div>
  );
};
