import styles from '../calendarvis.module.scss';

const DayNames = {
  0: 'Mon',
  2: 'Wed',
  4: 'Fri',
  6: 'Sun',
};

function Cell({ color, data, date }) {
  let style = {
    backgroundColor: color,
  };
  color;

  const handleClick = (event) => {
    console.log(date, data);
  };

  return <div onMouseOver={handleClick} className={styles['timeline-cells-cell'] + ' rounded-sm'} style={style}></div>;
}

function Month({ startDate, index }) {
  let date = new Date(startDate.valueOf());
  date.setDate(startDate.getDate() + index * 7);

  let monthName = date.toLocaleString('default', { month: 'short' });

  return <div className={styles['timeline-months-month'] + ' text-[0.8rem] ' + styles[monthName]}>{monthName}</div>;
}

function WeekDay({ index }) {
  return <div className={styles['timeline-weekdays-weekday'] + ' text-[0.8rem] rounded-sm'}>{DayNames[index]}</div>;
}

export function Timeline({ range, data, colorFunc }) {
  const diffTime = Math.abs(range[1] - range[0]);
  const days = Math.ceil(diffTime / (1000 * 60 * 60 * 24));

  // console.log(days, range[0], range[1]);

  //   let days = Math.abs(range[0].diff(range[1], 'days'));
  let cells = Array.from(new Array(days));
  let weekDays = Array.from(new Array(7));
  let months = Array.from(new Array(Math.floor(days / 7)));

  let min = Math.min(0, ...data.map((d) => d.value));
  let max = Math.max(...data.map((d) => d.value));

  let colorMultiplier = 1 / (max - min);

  let startDate = range[0];
  const DayFormat = 'DDMMYYYY';

  return (
    <div className={styles['timeline'] + ' m-8'}>
      <div className={styles['timeline-months']}>
        {months.map((_, index) => (
          <Month key={index} index={index} startDate={startDate} />
        ))}
      </div>

      <div className={styles['timeline-body']}>
        <div className={styles['timeline-weekdays'] + ' mr-1'}>
          {weekDays.map((_, index) => (
            <WeekDay key={index} index={index} startDate={startDate} />
          ))}
        </div>

        <div className={styles['timeline-cells']}>
          {cells.map((_, index) => {
            let currentDay = new Date();
            currentDay.setDate(startDate.getDate() + index);

            let dataPoint = data.find((d) => {
              let currentDayNoClock = new Date(currentDay);
              currentDayNoClock.setHours(0, 0, 0, 0);

              let dataDateNoClock = new Date(d.date);
              dataDateNoClock.setHours(0, 0, 0, 0);

              return currentDayNoClock.getTime() === dataDateNoClock.getTime();
            });
            // if (!dataPoint) return;
            let alpha = colorMultiplier * dataPoint.value;
            let color = colorFunc({ alpha });
            // console.log(dataPoint);

            return <Cell key={index} index={index} data={dataPoint} date={currentDay} color={color} />;
          })}
        </div>
      </div>
    </div>
  );
}
